@@ -1,15 +1,24 @@
+import gc
 import unittest
 
 try:
-    import IPython  # noqa
+    import ipykernel  # noqa: F401
 except ImportError:
-    from nose.plugins.skip import SkipTest
-    raise SkipTest('IPython not available')
-
-from ipykernel.kernelapp import IPKernelApp
-from envisage.plugins.ipython_kernel.internal_ipkernel import InternalIPKernel
+    ipykernel_available = False
+else:
+    ipykernel_available = True
 
 
+if ipykernel_available:
+    from ipykernel.iostream import IOPubThread
+    from ipykernel.kernelapp import IPKernelApp
+
+    from envisage.plugins.ipython_kernel.internal_ipkernel import (
+        InternalIPKernel)
+
+
+@unittest.skipUnless(ipykernel_available,
+                     "skipping tests that require the ipykernel package")
 class TestInternalIPKernel(unittest.TestCase):
 
     def tearDown(self):
@@ -37,3 +46,18 @@ class TestInternalIPKernel(unittest.TestCase):
         self.assertIn('x', kernel.namespace)
         self.assertEqual(kernel.namespace['x'], 42.1)
         kernel.shutdown()
+
+    def test_io_pub_thread_stopped(self):
+        kernel = InternalIPKernel()
+        kernel.init_ipkernel(gui_backend=None)
+        kernel.new_qt_console()
+        kernel.new_qt_console()
+        kernel.shutdown()
+
+        io_pub_threads = [
+            obj for obj in gc.get_objects()
+            if isinstance(obj, IOPubThread)
+        ]
+
+        for thread in io_pub_threads:
+            self.assertFalse(thread.thread.is_alive())
